referrerpolicy=no-referrer-when-downgrade

CurrentPlannedSession

Type Alias CurrentPlannedSession 

pub type CurrentPlannedSession<T> = StorageValue<_GeneratedPrefixForStorageCurrentPlannedSession<T>, SessionIndex, ValueQuery>;
The last planned session scheduled by the session pallet.

This is basically in sync with the call to [pallet_session::SessionManager::new_session].

Storage type is [StorageValue] with value type SessionIndex.

Aliased Type

pub struct CurrentPlannedSession<T>(/* private fields */);