referrerpolicy=no-referrer-when-downgrade

SpanSlash

Type Alias SpanSlash 

pub type SpanSlash<T: Config> = StorageMap<_GeneratedPrefixForStorageSpanSlash<T>, Twox64Concat, (T::AccountId, SpanIndex), SpanRecord<BalanceOf<T>>, ValueQuery>;
Records information about the maximum slash of a stash within a slashing span, as well as how much reward has been paid out.

Storage type is [StorageMap] with key type (T :: AccountId, slashing :: SpanIndex) and value type slashing :: SpanRecord < BalanceOf < T > >.

Aliased Type

pub struct SpanSlash<T: Config>(/* private fields */);